.onAttach <-
  function(libname, pkgname) {

    welcomeString =sprintf("%s %s\n%s (%s)",
                        .QC$package.name,
                        .QC$script.version,
                      #  .QC$vignetteLink,
                        .QC$help,
                        .QC$url)

    packageStartupMessage(welcomeString)

  }


.onLoad <- function(libname, pkgname) {

}


utils::globalVariables(c('PVALUE',
                       'PVALUE.calculated',
                       'logP',
                       'expected.logP',
                       'cupper',
                       'clower',
                       'hID',
                       'CHR',
                       'POSITION',
                       'VT',
                       'EFFECT_ALL',
                       'OTHER_ALL',
                       'ALT',
                       'REF',
                       'found',
                       'palindromic',
                       'flip',
                       'wrong',
                       'HQ',
                       'EFF_ALL_FREQ',
                       'IMP_QUALITY',
                       'HWE_PVAL',
                       'CALLRATE',
                       'EFFECT',
                       'STDERR',
                       'SOURCE',
                       'AF',
                       'PVALUE',
                       'IMPUTED',
                       'highDiffEAF',
                       'DATE_ADDED',
                       'allele',
                       'precisionPlotPath',
                       'skew_kurtPlotPath',
                       'effsizePlotPath',
                       'MULTI_ALLELIC',
                       'ID',
                       'EFFECT.y',
                       'N',
                       'Count',
                       'reference.data',
                       'alt.reference.data',
                       'reference.data.effect',
                       'report.output.path',
                       'SE.mean.HQ',
                       'sqrt.n',
                       'ordered.names',
                       'skewness',
                       'kurtosis',
                       'EFFECT.x',
                       'lm',
                       'frq',
                       'expected.logP2',
                       'expected.logP3',
                       'expected.logP4',
                       'hwp',
                       'impq',
                       'expected.logP5',
                       'plot.title',
                       'final.plot',
                       'OR',
                       'N_TOTAL',
                       'STRAND',
                       'x',
                       'y0',
                       'y25',
                       'y50',
                       'y75',
                       'y100',
                       'CHR.y',
                       'POS',
                       'MARKER',
                       'build',
                       'pgc',
                       'sebeta',
                       'lambda.estimate',
                       'lambda.se',
					   'SWITCHED_EFFECT_ALL',
                       'SWITCHED_OTHER_ALL',
                       '..density..',
                       '.',
					              'match_result'))
